@@ -26,7 +26,7 @@
  *
  */
 
-static const char revision[] = "$Id: qsfilter2.c 2480 2018-08-27 20:20:04Z pbuchbinder $";
+static const char revision[] = "$Id: qsfilter2.c 2486 2018-09-03 20:22:17Z pbuchbinder $";
 
 /* system */
 #include <stdio.h>
@@ -545,7 +545,7 @@ static void usage(char *cmd, int man) {
   printf("\n");
   if(man) {
     printf(".SH SEE ALSO\n");
-    printf("qsdt(1), qsexec(1), qsgeo(1), qsgrep(1), qshead(1), qslog(1), qslogger(1), qspng(1), qsrotate(1), qssign(1), qstail(1)\n");
+    printf("qsdt(1), qsexec(1), qsgeo(1), qsgrep(1), qshead(1), qslog(1), qslogger(1), qspng(1), qsre(1), qsrespeed(1), qsrotate(1), qssign(1), qstail(1)\n");
     printf(".SH AUTHOR\n");
     printf("Pascal Buchbinder, http://mod-qos.sourceforge.net/\n");
   } else {
