@@ -27,7 +27,7 @@
  *
  */
 
-static const char revision[] = "$Id: qsgeo.c 2480 2018-08-27 20:20:04Z pbuchbinder $";
+static const char revision[] = "$Id: qsgeo.c 2486 2018-09-03 20:22:17Z pbuchbinder $";
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -240,7 +240,7 @@ static void usage(const char *cmd, int man) {
   printf("\n");
   if(man) {
     printf(".SH SEE ALSO\n");
-    printf("qsdt(1), qsexec(1), qsfilter2(1), qsgrep(1), qshead(1), qslog(1), qslogger(1), qspng(1), qsrotate(1), qssign(1), qstail(1)\n");
+    printf("qsdt(1), qsexec(1), qsfilter2(1), qsgrep(1), qshead(1), qslog(1), qslogger(1), qspng(1), qsre(1), qsrespeed(1), qsrotate(1), qssign(1), qstail(1)\n");
     printf(".SH AUTHOR\n");
     printf("Pascal Buchbinder, http://mod-qos.sourceforge.net/\n");
   } else {
